<?php

namespace Drupal\webform_simplify;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Session\AccountProxyInterface;

/**
 * Hide certain parts of Webform settings.
 */
class WebformSettingsAlter {

  /**
   * The current user.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  public function __construct(
    AccountProxyInterface $currentUser,
    ConfigFactoryInterface $configFactory
  ) {
    $this->currentUser = $currentUser;
    $this->configFactory = $configFactory;
  }

  /**
   * Hide certain parts of element forms.
   */
  public function alter(array &$form): void {
    if ($this->currentUser->hasPermission('bypass webform simplification')) {
      return;
    }

    $config = $this->configFactory->get('webform_simplify.settings');

    $confirmationTypes = &$form['confirmation_type']['confirmation_type']['#options'];
    $disabledConfirmationTypes = $config->get('webform_settings.disabled_confirmation_types') ?? [];
    $enabledConfirmationTypes = array_diff_key($confirmationTypes, array_flip($disabledConfirmationTypes));
    $confirmationTypes = $enabledConfirmationTypes;
  }

}
